==> maven-jredmine-plugin-1.0.2-sources.jar: org/nuiton/jredmine/plugin/announcement/GenerateNewsAnnouncementMojo.java <==
/*
 * *##% 
 * JRedmine maven plugin
 * Copyright (C) 2009 CodeLutin
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * ##%*
 */
package org.nuiton.jredmine.plugin.announcement;

/**
 * Generate the content of the release announcement news for Redmine.
 *
 * @goal generate-news-announcement
 *
 * @author tchemit
 * @since 1.0.0
 */
public class GenerateNewsAnnouncementMojo extends AbstractAnnouncementMojo {

    /**
     * The Velocity template used to format the redmine announcement.
     *
     * @parameter expression="${redmine.newsAnnouncementTemplate}" default-value="release-news-announcement.vm"
     * @required
     * @since 1.0.0
     */
    private String newsAnnouncementTemplate;
    /**
     * A flag to enable or disable the goal.
     *
     * @parameter expression="${redmine.skipGenerateNewsAnnouncement}" default-value="false"
     * @since 1.0.0
     */
    private boolean skipGenerateNewsAnnouncement;

    @Override
    protected String getAnnouncementTemplate() {
        return newsAnnouncementTemplate;
    }

    @Override
    protected boolean isGoalSkip() {
        return skipGenerateNewsAnnouncement;
    }
}

==> maven-jredmine-plugin-1.1-sources.jar: org/nuiton/jredmine/plugin/announcement/GenerateNewsAnnouncementMojo.java <==
/*
 * *##% 
 * JRedmine maven plugin
 * Copyright (C) 2009 CodeLutin
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * ##%*
 */
package org.nuiton.jredmine.plugin.announcement;

/**
 * Generate the content of the release announcement news for Redmine.
 *
 * @author tchemit
 * @goal generate-news-announcement
 * @since 1.0.0
 */
public class GenerateNewsAnnouncementMojo extends AbstractAnnouncementMojo {

    /**
     * The Velocity template used to format the redmine announcement.
     *
     * @parameter expression="${redmine.newsAnnouncementTemplate}" default-value="release-news-announcement.vm"
     * @required
     * @since 1.0.0
     */
    protected String newsAnnouncementTemplate;
    /**
     * A flag to enable or disable the goal.
     *
     * @parameter expression="${redmine.skipGenerateNewsAnnouncement}" default-value="false"
     * @since 1.0.0
     */
    protected boolean skipGenerateNewsAnnouncement;

    @Override
    protected String getAnnouncementTemplate() {
        return newsAnnouncementTemplate;
    }

    @Override
    protected boolean isGoalSkip() {
        return skipGenerateNewsAnnouncement;
    }
}
